@@ -71,7 +71,7 @@ interpolateRaster <- function(inputRaster, fast = FALSE, ...){
   }
 
   # Input error check
-  if (!class(inputRaster) == "RasterLayer") {
+  if (!is(inputRaster, "RasterLayer")) {
     warning(paste0("inputRaster is not of class 'RasterLayer'.\n"))
     return(NULL)
   }
@@ -153,14 +153,11 @@ interpolateRaster <- function(inputRaster, fast = FALSE, ...){
 #' values(r) <- 1:10000
 #'
 #' # Introduce a "bubble"
-#' values(r)[520:525] <- 9999
+#' values(r)[720:725] <- 9999
 #' plot(r)
 #'
 #' # Smooth bubble with smoothRaster
-#' smoothedRaster <- smoothRaster(r)
-#' plot(smoothedRaster)
-#'
-#' fastSmooth <- smoothRaster(r, fast = TRUE, aRange = 3.0)
+#' fastSmooth <- smoothRaster(r, fast = TRUE, aRange = 10.0)
 #' plot(fastSmooth)
 #'
 #' @import raster
@@ -197,7 +194,7 @@ smoothRaster <- function(inputRaster, fast = FALSE, ...){
   }
 
   # Input error check
-  if (!class(inputRaster) == "RasterLayer") {
+  if (!is(inputRaster, "RasterLayer")) {
     warning(paste0("inputRaster is not of class 'RasterLayer'.\n"))
     return(NULL)
   }
